# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .alert import *
from .alert_target import *
from .cloud_integration_app_dynamics import *
from .cloud_integration_aws_external_id import *
from .cloud_integration_azure import *
from .cloud_integration_azure_activity_log import *
from .cloud_integration_cloud_trail import *
from .cloud_integration_cloud_watch import *
from .cloud_integration_ec2 import *
from .cloud_integration_gcp import *
from .cloud_integration_gcp_billing import *
from .cloud_integration_new_relic import *
from .dashboard import *
from .dashboard_json import *
from .derived_metric import *
from .event import *
from .external_link import *
from .get_alert import *
from .get_alerts import *
from .get_dashboard import *
from .get_dashboards import *
from .get_default_user_group import *
from .get_derived_metric import *
from .get_derived_metrics import *
from .get_event import *
from .get_events import *
from .get_external_link import *
from .get_external_links import *
from .get_maintenance_window import *
from .get_maintenance_window_all import *
from .get_metrics_policy import *
from .get_role import *
from .get_roles import *
from .get_user import *
from .get_user_group import *
from .get_user_groups import *
from .get_users import *
from .ingestion_policy import *
from .maintenance_window import *
from .metrics_policy import *
from .provider import *
from .role import *
from .service_account import *
from .user import *
from .user_group import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_wavefront.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_wavefront.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "wavefront",
  "mod": "index/alert",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/alert:Alert": "Alert"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/alertTarget",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/alertTarget:AlertTarget": "AlertTarget"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/cloudIntegrationAppDynamics",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/cloudIntegrationAppDynamics:CloudIntegrationAppDynamics": "CloudIntegrationAppDynamics"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/cloudIntegrationAwsExternalId",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/cloudIntegrationAwsExternalId:CloudIntegrationAwsExternalId": "CloudIntegrationAwsExternalId"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/cloudIntegrationAzure",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/cloudIntegrationAzure:CloudIntegrationAzure": "CloudIntegrationAzure"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/cloudIntegrationAzureActivityLog",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/cloudIntegrationAzureActivityLog:CloudIntegrationAzureActivityLog": "CloudIntegrationAzureActivityLog"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/cloudIntegrationCloudTrail",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/cloudIntegrationCloudTrail:CloudIntegrationCloudTrail": "CloudIntegrationCloudTrail"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/cloudIntegrationCloudWatch",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/cloudIntegrationCloudWatch:CloudIntegrationCloudWatch": "CloudIntegrationCloudWatch"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/cloudIntegrationEc2",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/cloudIntegrationEc2:CloudIntegrationEc2": "CloudIntegrationEc2"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/cloudIntegrationGcp",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/cloudIntegrationGcp:CloudIntegrationGcp": "CloudIntegrationGcp"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/cloudIntegrationGcpBilling",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/cloudIntegrationGcpBilling:CloudIntegrationGcpBilling": "CloudIntegrationGcpBilling"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/cloudIntegrationNewRelic",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/cloudIntegrationNewRelic:CloudIntegrationNewRelic": "CloudIntegrationNewRelic"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/dashboard",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/dashboard:Dashboard": "Dashboard"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/dashboardJson",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/dashboardJson:DashboardJson": "DashboardJson"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/derivedMetric",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/derivedMetric:DerivedMetric": "DerivedMetric"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/event",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/event:Event": "Event"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/externalLink",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/externalLink:ExternalLink": "ExternalLink"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/ingestionPolicy",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/ingestionPolicy:IngestionPolicy": "IngestionPolicy"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/maintenanceWindow",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/maintenanceWindow:MaintenanceWindow": "MaintenanceWindow"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/metricsPolicy",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/metricsPolicy:MetricsPolicy": "MetricsPolicy"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/role",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/role:Role": "Role"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/serviceAccount",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/serviceAccount:ServiceAccount": "ServiceAccount"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/user",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/user:User": "User"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/userGroup",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/userGroup:UserGroup": "UserGroup"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "wavefront",
  "token": "pulumi:providers:wavefront",
  "fqn": "pulumi_wavefront",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

address: Optional[str]

httpProxy: Optional[str]

token: Optional[str]




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetUsersResult',
    'AwaitableGetUsersResult',
    'get_users',
    'get_users_output',
]

@pulumi.output_type
class GetUsersResult:
    """
    A collection of values returned by getUsers.
    """
    def __init__(__self__, id=None, users=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if users and not isinstance(users, list):
            raise TypeError("Expected argument 'users' to be a list")
        pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def users(self) -> Sequence['outputs.GetUsersUserResult']:
        """
        List of all users in Wavefront.
        """
        return pulumi.get(self, "users")


class AwaitableGetUsersResult(GetUsersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUsersResult(
            id=self.id,
            users=self.users)


def get_users(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUsersResult:
    """
    Use this data source to get all users in Wavefront.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_wavefront as wavefront

    # Get all users
    users = wavefront.get_users()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('wavefront:index/getUsers:getUsers', __args__, opts=opts, typ=GetUsersResult).value

    return AwaitableGetUsersResult(
        id=pulumi.get(__ret__, 'id'),
        users=pulumi.get(__ret__, 'users'))


@_utilities.lift_output_func(get_users)
def get_users_output(opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetUsersResult]:
    """
    Use this data source to get all users in Wavefront.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_wavefront as wavefront

    # Get all users
    users = wavefront.get_users()
    ```
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetDerivedMetricsResult',
    'AwaitableGetDerivedMetricsResult',
    'get_derived_metrics',
    'get_derived_metrics_output',
]

@pulumi.output_type
class GetDerivedMetricsResult:
    """
    A collection of values returned by getDerivedMetrics.
    """
    def __init__(__self__, derived_metrics=None, id=None, limit=None, offset=None):
        if derived_metrics and not isinstance(derived_metrics, list):
            raise TypeError("Expected argument 'derived_metrics' to be a list")
        pulumi.set(__self__, "derived_metrics", derived_metrics)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if limit and not isinstance(limit, int):
            raise TypeError("Expected argument 'limit' to be a int")
        pulumi.set(__self__, "limit", limit)
        if offset and not isinstance(offset, int):
            raise TypeError("Expected argument 'offset' to be a int")
        pulumi.set(__self__, "offset", offset)

    @property
    @pulumi.getter(name="derivedMetrics")
    def derived_metrics(self) -> Sequence['outputs.GetDerivedMetricsDerivedMetricResult']:
        """
        List of all derived metrics in Wavefront. For each derived metric you will see a list of attributes.
        """
        return pulumi.get(self, "derived_metrics")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def limit(self) -> Optional[int]:
        return pulumi.get(self, "limit")

    @property
    @pulumi.getter
    def offset(self) -> Optional[int]:
        return pulumi.get(self, "offset")


class AwaitableGetDerivedMetricsResult(GetDerivedMetricsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDerivedMetricsResult(
            derived_metrics=self.derived_metrics,
            id=self.id,
            limit=self.limit,
            offset=self.offset)


def get_derived_metrics(limit: Optional[int] = None,
                        offset: Optional[int] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDerivedMetricsResult:
    """
    Use this data source to get information about all Wavefront derived metrics.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_wavefront as wavefront

    # Get the information about all derived metrics.
    example = wavefront.get_derived_metrics(limit=10,
        offset=0)
    ```


    :param int limit: Limit is the maximum number of results to be returned. Defaults to 100.
    :param int offset: Offset is the offset from the first result to be returned. Defaults to 0.
    """
    __args__ = dict()
    __args__['limit'] = limit
    __args__['offset'] = offset
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('wavefront:index/getDerivedMetrics:getDerivedMetrics', __args__, opts=opts, typ=GetDerivedMetricsResult).value

    return AwaitableGetDerivedMetricsResult(
        derived_metrics=pulumi.get(__ret__, 'derived_metrics'),
        id=pulumi.get(__ret__, 'id'),
        limit=pulumi.get(__ret__, 'limit'),
        offset=pulumi.get(__ret__, 'offset'))


@_utilities.lift_output_func(get_derived_metrics)
def get_derived_metrics_output(limit: Optional[pulumi.Input[Optional[int]]] = None,
                               offset: Optional[pulumi.Input[Optional[int]]] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDerivedMetricsResult]:
    """
    Use this data source to get information about all Wavefront derived metrics.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_wavefront as wavefront

    # Get the information about all derived metrics.
    example = wavefront.get_derived_metrics(limit=10,
        offset=0)
    ```


    :param int limit: Limit is the maximum number of results to be returned. Defaults to 100.
    :param int offset: Offset is the offset from the first result to be returned. Defaults to 0.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['DashboardJsonArgs', 'DashboardJson']

@pulumi.input_type
class DashboardJsonArgs:
    def __init__(__self__, *,
                 dashboard_json: pulumi.Input[str]):
        """
        The set of arguments for constructing a DashboardJson resource.
        :param pulumi.Input[str] dashboard_json: See the [Wavefront API Documentation](https://docs.wavefront.com/wavefront_api.html#api-documentation-wavefront-instance)
               for instructions on how to get to your API documentation for more details.
        """
        pulumi.set(__self__, "dashboard_json", dashboard_json)

    @property
    @pulumi.getter(name="dashboardJson")
    def dashboard_json(self) -> pulumi.Input[str]:
        """
        See the [Wavefront API Documentation](https://docs.wavefront.com/wavefront_api.html#api-documentation-wavefront-instance)
        for instructions on how to get to your API documentation for more details.
        """
        return pulumi.get(self, "dashboard_json")

    @dashboard_json.setter
    def dashboard_json(self, value: pulumi.Input[str]):
        pulumi.set(self, "dashboard_json", value)


@pulumi.input_type
class _DashboardJsonState:
    def __init__(__self__, *,
                 dashboard_json: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering DashboardJson resources.
        :param pulumi.Input[str] dashboard_json: See the [Wavefront API Documentation](https://docs.wavefront.com/wavefront_api.html#api-documentation-wavefront-instance)
               for instructions on how to get to your API documentation for more details.
        """
        if dashboard_json is not None:
            pulumi.set(__self__, "dashboard_json", dashboard_json)

    @property
    @pulumi.getter(name="dashboardJson")
    def dashboard_json(self) -> Optional[pulumi.Input[str]]:
        """
        See the [Wavefront API Documentation](https://docs.wavefront.com/wavefront_api.html#api-documentation-wavefront-instance)
        for instructions on how to get to your API documentation for more details.
        """
        return pulumi.get(self, "dashboard_json")

    @dashboard_json.setter
    def dashboard_json(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dashboard_json", value)


class DashboardJson(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dashboard_json: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Wavefront Dashboard JSON resource. This allows dashboards to be created, updated, and deleted.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_wavefront as wavefront

        test_dashboard_json = wavefront.DashboardJson("test_dashboard_json", dashboard_json=\"\"\"{
          "acl": {
            "canModify": [
              "group-uuid",
              "role-uuid"
            ],
            "canView": [
              "group-uuid",
              "role-uuid"
            ]
          },
          "name": "Terraform Test Dashboard Json",
          "description": "a",
          "eventFilterType": "BYCHART",
          "eventQuery": "",
          "defaultTimeWindow": "",
          "url": "tftestimport",
          "displayDescription": false,
          "displaySectionTableOfContents": true,
          "displayQueryParameters": false,
          "sections": [
            {
              "name": "section 1",
              "rows": [
                {
                  "charts": [
                    {
                      "name": "chart 1",
                      "sources": [
                        {
                          "name": "source 1",
                          "query": "ts()",
                          "scatterPlotSource": "Y",
                          "querybuilderEnabled": false,
                          "sourceDescription": ""
                        }
                      ],
                      "units": "someunit",
                      "base": 0,
                      "noDefaultEvents": false,
                      "interpolatePoints": false,
                      "includeObsoleteMetrics": false,
                      "description": "This is chart 1, showing something",
                      "chartSettings": {
                        "type": "markdown-widget",
                        "max": 100,
                        "expectedDataSpacing": 120,
                        "windowing": "full",
                        "windowSize": 10,
                        "autoColumnTags": false,
                        "columnTags": "deprecated",
                        "tagMode": "all",
                        "numTags": 2,
                        "customTags": [
                          "tag1",
                          "tag2"
                        ],
                        "groupBySource": true,
                        "y1Max": 100,
                        "y1Units": "units",
                        "y0ScaleSIBy1024": true,
                        "y1ScaleSIBy1024": true,
                        "y0UnitAutoscaling": true,
                        "y1UnitAutoscaling": true,
                        "fixedLegendEnabled": true,
                        "fixedLegendUseRawStats": true,
                        "fixedLegendPosition": "RIGHT",
                        "fixedLegendDisplayStats": [
                          "stat1",
                          "stat2"
                        ],
                        "fixedLegendFilterSort": "TOP",
                        "fixedLegendFilterLimit": 1,
                        "fixedLegendFilterField": "CURRENT",
                        "plainMarkdownContent": "markdown content"
                      },
                      "chartAttributes": {
                        "dashboardLinks": {
                          "*": {
                            "variables": {
                              "xxx": "xxx"
                            },
                            "destination": "/dashboards/xxxx"
                          }
                        }
                      },
                      "summarization": "MEAN"
                    }
                  ],
                  "heightFactor": 50
                }
              ]
            }
          ],
          "parameterDetails": {
            "param": {
              "hideFromView": false,
              "description": null,
              "allowAll": null,
              "tagKey": null,
              "queryValue": null,
              "dynamicFieldType": null,
              "reverseDynSort": null,
              "parameterType": "SIMPLE",
              "label": "test",
              "defaultValue": "Label",
              "valuesToReadableStrings": {
                "Label": "test"
              },
              "selectedLabel": "Label",
              "value": "test"
            }
          },
          "tags": {
            "customerTags": [
              "terraform"
            ]
          }
        }
        \"\"\")
        ```

        * 
        *Note:
        ** If there are dynamic variables in the Wavefront dashboard json, then these variables must be present in a separate file as mentioned in the section below.

        ## Import

        Dashboard JSON can be imported by using the `id`, e.g.:

        ```sh
        $ pulumi import wavefront:index/dashboardJson:DashboardJson dashboard_json tftestimport
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] dashboard_json: See the [Wavefront API Documentation](https://docs.wavefront.com/wavefront_api.html#api-documentation-wavefront-instance)
               for instructions on how to get to your API documentation for more details.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DashboardJsonArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Wavefront Dashboard JSON resource. This allows dashboards to be created, updated, and deleted.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_wavefront as wavefront

        test_dashboard_json = wavefront.DashboardJson("test_dashboard_json", dashboard_json=\"\"\"{
          "acl": {
            "canModify": [
              "group-uuid",
              "role-uuid"
            ],
            "canView": [
              "group-uuid",
              "role-uuid"
            ]
          },
          "name": "Terraform Test Dashboard Json",
          "description": "a",
          "eventFilterType": "BYCHART",
          "eventQuery": "",
          "defaultTimeWindow": "",
          "url": "tftestimport",
          "displayDescription": false,
          "displaySectionTableOfContents": true,
          "displayQueryParameters": false,
          "sections": [
            {
              "name": "section 1",
              "rows": [
                {
                  "charts": [
                    {
                      "name": "chart 1",
                      "sources": [
                        {
                          "name": "source 1",
                          "query": "ts()",
                          "scatterPlotSource": "Y",
                          "querybuilderEnabled": false,
                          "sourceDescription": ""
                        }
                      ],
                      "units": "someunit",
                      "base": 0,
                      "noDefaultEvents": false,
                      "interpolatePoints": false,
                      "includeObsoleteMetrics": false,
                      "description": "This is chart 1, showing something",
                      "chartSettings": {
                        "type": "markdown-widget",
                        "max": 100,
                        "expectedDataSpacing": 120,
                        "windowing": "full",
                        "windowSize": 10,
                        "autoColumnTags": false,
                        "columnTags": "deprecated",
                        "tagMode": "all",
                        "numTags": 2,
                        "customTags": [
                          "tag1",
                          "tag2"
                        ],
                        "groupBySource": true,
                        "y1Max": 100,
                        "y1Units": "units",
                        "y0ScaleSIBy1024": true,
                        "y1ScaleSIBy1024": true,
                        "y0UnitAutoscaling": true,
                        "y1UnitAutoscaling": true,
                        "fixedLegendEnabled": true,
                        "fixedLegendUseRawStats": true,
                        "fixedLegendPosition": "RIGHT",
                        "fixedLegendDisplayStats": [
                          "stat1",
                          "stat2"
                        ],
                        "fixedLegendFilterSort": "TOP",
                        "fixedLegendFilterLimit": 1,
                        "fixedLegendFilterField": "CURRENT",
                        "plainMarkdownContent": "markdown content"
                      },
                      "chartAttributes": {
                        "dashboardLinks": {
                          "*": {
                            "variables": {
                              "xxx": "xxx"
                            },
                            "destination": "/dashboards/xxxx"
                          }
                        }
                      },
                      "summarization": "MEAN"
                    }
                  ],
                  "heightFactor": 50
                }
              ]
            }
          ],
          "parameterDetails": {
            "param": {
              "hideFromView": false,
              "description": null,
              "allowAll": null,
              "tagKey": null,
              "queryValue": null,
              "dynamicFieldType": null,
              "reverseDynSort": null,
              "parameterType": "SIMPLE",
              "label": "test",
              "defaultValue": "Label",
              "valuesToReadableStrings": {
                "Label": "test"
              },
              "selectedLabel": "Label",
              "value": "test"
            }
          },
          "tags": {
            "customerTags": [
              "terraform"
            ]
          }
        }
        \"\"\")
        ```

        * 
        *Note:
        ** If there are dynamic variables in the Wavefront dashboard json, then these variables must be present in a separate file as mentioned in the section below.

        ## Import

        Dashboard JSON can be imported by using the `id`, e.g.:

        ```sh
        $ pulumi import wavefront:index/dashboardJson:DashboardJson dashboard_json tftestimport
        ```

        :param str resource_name: The name of the resource.
        :param DashboardJsonArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DashboardJsonArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dashboard_json: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DashboardJsonArgs.__new__(DashboardJsonArgs)

            if dashboard_json is None and not opts.urn:
                raise TypeError("Missing required property 'dashboard_json'")
            __props__.__dict__["dashboard_json"] = dashboard_json
        super(DashboardJson, __self__).__init__(
            'wavefront:index/dashboardJson:DashboardJson',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            dashboard_json: Optional[pulumi.Input[str]] = None) -> 'DashboardJson':
        """
        Get an existing DashboardJson resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] dashboard_json: See the [Wavefront API Documentation](https://docs.wavefront.com/wavefront_api.html#api-documentation-wavefront-instance)
               for instructions on how to get to your API documentation for more details.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DashboardJsonState.__new__(_DashboardJsonState)

        __props__.__dict__["dashboard_json"] = dashboard_json
        return DashboardJson(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="dashboardJson")
    def dashboard_json(self) -> pulumi.Output[str]:
        """
        See the [Wavefront API Documentation](https://docs.wavefront.com/wavefront_api.html#api-documentation-wavefront-instance)
        for instructions on how to get to your API documentation for more details.
        """
        return pulumi.get(self, "dashboard_json")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['CloudIntegrationCloudWatchArgs', 'CloudIntegrationCloudWatch']

@pulumi.input_type
class CloudIntegrationCloudWatchArgs:
    def __init__(__self__, *,
                 external_id: pulumi.Input[str],
                 role_arn: pulumi.Input[str],
                 service: pulumi.Input[str],
                 additional_tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 force_save: Optional[pulumi.Input[bool]] = None,
                 instance_selection_tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 metric_filter_regex: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespaces: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 point_tag_filter_regex: Optional[pulumi.Input[str]] = None,
                 service_refresh_rate_in_minutes: Optional[pulumi.Input[int]] = None,
                 volume_selection_tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a CloudIntegrationCloudWatch resource.
        :param pulumi.Input[str] external_id: The Role ARN that the customer has created in AWS IAM to allow access to Wavefront.
        :param pulumi.Input[str] role_arn: The external ID corresponding to the Role ARN.
        :param pulumi.Input[str] service: A value denoting which cloud service this service integrates with.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] additional_tags: A list of point tag key-values to add to every point ingested using this integration.
        :param pulumi.Input[bool] force_save: Forces this resource to save, even if errors are present.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] instance_selection_tags: A string->string map allow list of instance tag-value pairs (in AWS).
               If the instance's AWS tags match this allow list, CloudWatch data about this instance is ingested.
               Multiple entries are OR'ed.
        :param pulumi.Input[str] metric_filter_regex: A regular expression that a CloudWatch metric name must match (case-insensitively) in order to be ingested.
        :param pulumi.Input[str] name: The human-readable name of this integration.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] namespaces: A list of namespaces that limit what we query from CloudWatch.
        :param pulumi.Input[str] point_tag_filter_regex: A regular expression that AWS tag key name must match (case-insensitively)
               in order to be ingested.
        :param pulumi.Input[int] service_refresh_rate_in_minutes: How often, in minutes, to refresh the service.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] volume_selection_tags: A string->string map of allow list of volume tag-value pairs (in AWS).
               If the volume's AWS tags match this allow list, CloudWatch data about this volume is ingested.
               Multiple entries are OR'ed.
        """
        pulumi.set(__self__, "external_id", external_id)
        pulumi.set(__self__, "role_arn", role_arn)
        pulumi.set(__self__, "service", service)
        if additional_tags is not None:
            pulumi.set(__self__, "additional_tags", additional_tags)
        if force_save is not None:
            pulumi.set(__self__, "force_save", force_save)
        if instance_selection_tags is not None:
            pulumi.set(__self__, "instance_selection_tags", instance_selection_tags)
        if metric_filter_regex is not None:
            pulumi.set(__self__, "metric_filter_regex", metric_filter_regex)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespaces is not None:
            pulumi.set(__self__, "namespaces", namespaces)
        if point_tag_filter_regex is not None:
            pulumi.set(__self__, "point_tag_filter_regex", point_tag_filter_regex)
        if service_refresh_rate_in_minutes is not None:
            pulumi.set(__self__, "service_refresh_rate_in_minutes", service_refresh_rate_in_minutes)
        if volume_selection_tags is not None:
            pulumi.set(__self__, "volume_selection_tags", volume_selection_tags)

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> pulumi.Input[str]:
        """
        The Role ARN that the customer has created in AWS IAM to allow access to Wavefront.
        """
        return pulumi.get(self, "external_id")

    @external_id.setter
    def external_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "external_id", value)

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> pulumi.Input[str]:
        """
        The external ID corresponding to the Role ARN.
        """
        return pulumi.get(self, "role_arn")

    @role_arn.setter
    def role_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "role_arn", value)

    @property
    @pulumi.getter
    def service(self) -> pulumi.Input[str]:
        """
        A value denoting which cloud service this service integrates with.
        """
        return pulumi.get(self, "service")

    @service.setter
    def service(self, value: pulumi.Input[str]):
        pulumi.set(self, "service", value)

    @property
    @pulumi.getter(name="additionalTags")
    def additional_tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A list of point tag key-values to add to every point ingested using this integration.
        """
        return pulumi.get(self, "additional_tags")

    @additional_tags.setter
    def additional_tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "additional_tags", value)

    @property
    @pulumi.getter(name="forceSave")
    def force_save(self) -> Optional[pulumi.Input[bool]]:
        """
        Forces this resource to save, even if errors are present.
        """
        return pulumi.get(self, "force_save")

    @force_save.setter
    def force_save(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "force_save", value)

    @property
    @pulumi.getter(name="instanceSelectionTags")
    def instance_selection_tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A string->string map allow list of instance tag-value pairs (in AWS).
        If the instance's AWS tags match this allow list, CloudWatch data about this instance is ingested.
        Multiple entries are OR'ed.
        """
        return pulumi.get(self, "instance_selection_tags")

    @instance_selection_tags.setter
    def instance_selection_tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "instance_selection_tags", value)

    @property
    @pulumi.getter(name="metricFilterRegex")
    def metric_filter_regex(self) -> Optional[pulumi.Input[str]]:
        """
        A regular expression that a CloudWatch metric name must match (case-insensitively) in order to be ingested.
        """
        return pulumi.get(self, "metric_filter_regex")

    @metric_filter_regex.setter
    def metric_filter_regex(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "metric_filter_regex", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The human-readable name of this integration.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def namespaces(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of namespaces that limit what we query from CloudWatch.
        """
        return pulumi.get(self, "namespaces")

    @namespaces.setter
    def namespaces(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "namespaces", value)

    @property
    @pulumi.getter(name="pointTagFilterRegex")
    def point_tag_filter_regex(self) -> Optional[pulumi.Input[str]]:
        """
        A regular expression that AWS tag key name must match (case-insensitively)
        in order to be ingested.
        """
        return pulumi.get(self, "point_tag_filter_regex")

    @point_tag_filter_regex.setter
    def point_tag_filter_regex(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "point_tag_filter_regex", value)

    @property
    @pulumi.getter(name="serviceRefreshRateInMinutes")
    def service_refresh_rate_in_minutes(self) -> Optional[pulumi.Input[int]]:
        """
        How often, in minutes, to refresh the service.
        """
        return pulumi.get(self, "service_refresh_rate_in_minutes")

    @service_refresh_rate_in_minutes.setter
    def service_refresh_rate_in_minutes(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "service_refresh_rate_in_minutes", value)

    @property
    @pulumi.getter(name="volumeSelectionTags")
    def volume_selection_tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A string->string map of allow list of volume tag-value pairs (in AWS).
        If the volume's AWS tags match this allow list, CloudWatch data about this volume is ingested.
        Multiple entries are OR'ed.
        """
        return pulumi.get(self, "volume_selection_tags")

    @volume_selection_tags.setter
    def volume_selection_tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "volume_selection_tags", value)


@pulumi.input_type
class _CloudIntegrationCloudWatchState:
    def __init__(__self__, *,
                 additional_tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 external_id: Optional[pulumi.Input[str]] = None,
                 force_save: Optional[pulumi.Input[bool]] = None,
                 instance_selection_tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 metric_filter_regex: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespaces: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 point_tag_filter_regex: Optional[pulumi.Input[str]] = None,
                 role_arn: Optional[pulumi.Input[str]] = None,
                 service: Optional[pulumi.Input[str]] = None,
                 service_refresh_rate_in_minutes: Optional[pulumi.Input[int]] = None,
                 volume_selection_tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering CloudIntegrationCloudWatch resources.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] additional_tags: A list of point tag key-values to add to every point ingested using this integration.
        :param pulumi.Input[str] external_id: The Role ARN that the customer has created in AWS IAM to allow access to Wavefront.
        :param pulumi.Input[bool] force_save: Forces this resource to save, even if errors are present.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] instance_selection_tags: A string->string map allow list of instance tag-value pairs (in AWS).
               If the instance's AWS tags match this allow list, CloudWatch data about this instance is ingested.
               Multiple entries are OR'ed.
        :param pulumi.Input[str] metric_filter_regex: A regular expression that a CloudWatch metric name must match (case-insensitively) in order to be ingested.
        :param pulumi.Input[str] name: The human-readable name of this integration.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] namespaces: A list of namespaces that limit what we query from CloudWatch.
        :param pulumi.Input[str] point_tag_filter_regex: A regular expression that AWS tag key name must match (case-insensitively)
               in order to be ingested.
        :param pulumi.Input[str] role_arn: The external ID corresponding to the Role ARN.
        :param pulumi.Input[str] service: A value denoting which cloud service this service integrates with.
        :param pulumi.Input[int] service_refresh_rate_in_minutes: How often, in minutes, to refresh the service.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] volume_selection_tags: A string->string map of allow list of volume tag-value pairs (in AWS).
               If the volume's AWS tags match this allow list, CloudWatch data about this volume is ingested.
               Multiple entries are OR'ed.
        """
        if additional_tags is not None:
            pulumi.set(__self__, "additional_tags", additional_tags)
        if external_id is not None:
            pulumi.set(__self__, "external_id", external_id)
        if force_save is not None:
            pulumi.set(__self__, "force_save", force_save)
        if instance_selection_tags is not None:
            pulumi.set(__self__, "instance_selection_tags", instance_selection_tags)
        if metric_filter_regex is not None:
            pulumi.set(__self__, "metric_filter_regex", metric_filter_regex)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespaces is not None:
            pulumi.set(__self__, "namespaces", namespaces)
        if point_tag_filter_regex is not None:
            pulumi.set(__self__, "point_tag_filter_regex", point_tag_filter_regex)
        if role_arn is not None:
            pulumi.set(__self__, "role_arn", role_arn)
        if service is not None:
            pulumi.set(__self__, "service", service)
        if service_refresh_rate_in_minutes is not None:
            pulumi.set(__self__, "service_refresh_rate_in_minutes", service_refresh_rate_in_minutes)
        if volume_selection_tags is not None:
            pulumi.set(__self__, "volume_selection_tags", volume_selection_tags)

    @property
    @pulumi.getter(name="additionalTags")
    def additional_tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A list of point tag key-values to add to every point ingested using this integration.
        """
        return pulumi.get(self, "additional_tags")

    @additional_tags.setter
    def additional_tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "additional_tags", value)

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Role ARN that the customer has created in AWS IAM to allow access to Wavefront.
        """
        return pulumi.get(self, "external_id")

    @external_id.setter
    def external_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_id", value)

    @property
    @pulumi.getter(name="forceSave")
    def force_save(self) -> Optional[pulumi.Input[bool]]:
        """
        Forces this resource to save, even if errors are present.
        """
        return pulumi.get(self, "force_save")

    @force_save.setter
    def force_save(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "force_save", value)

    @property
    @pulumi.getter(name="instanceSelectionTags")
    def instance_selection_tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A string->string map allow list of instance tag-value pairs (in AWS).
        If the instance's AWS tags match this allow list, CloudWatch data about this instance is ingested.
        Multiple entries are OR'ed.
        """
        return pulumi.get(self, "instance_selection_tags")

    @instance_selection_tags.setter
    def instance_selection_tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "instance_selection_tags", value)

    @property
    @pulumi.getter(name="metricFilterRegex")
    def metric_filter_regex(self) -> Optional[pulumi.Input[str]]:
        """
        A regular expression that a CloudWatch metric name must match (case-insensitively) in order to be ingested.
        """
        return pulumi.get(self, "metric_filter_regex")

    @metric_filter_regex.setter
    def metric_filter_regex(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "metric_filter_regex", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The human-readable name of this integration.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def namespaces(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of namespaces that limit what we query from CloudWatch.
        """
        return pulumi.get(self, "namespaces")

    @namespaces.setter
    def namespaces(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "namespaces", value)

    @property
    @pulumi.getter(name="pointTagFilterRegex")
    def point_tag_filter_regex(self) -> Optional[pulumi.Input[str]]:
        """
        A regular expression that AWS tag key name must match (case-insensitively)
        in order to be ingested.
        """
        return pulumi.get(self, "point_tag_filter_regex")

    @point_tag_filter_regex.setter
    def point_tag_filter_regex(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "point_tag_filter_regex", value)

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The external ID corresponding to the Role ARN.
        """
        return pulumi.get(self, "role_arn")

    @role_arn.setter
    def role_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role_arn", value)

    @property
    @pulumi.getter
    def service(self) -> Optional[pulumi.Input[str]]:
        """
        A value denoting which cloud service this service integrates with.
        """
        return pulumi.get(self, "service")

    @service.setter
    def service(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service", value)

    @property
    @pulumi.getter(name="serviceRefreshRateInMinutes")
    def service_refresh_rate_in_minutes(self) -> Optional[pulumi.Input[int]]:
        """
        How often, in minutes, to refresh the service.
        """
        return pulumi.get(self, "service_refresh_rate_in_minutes")

    @service_refresh_rate_in_minutes.setter
    def service_refresh_rate_in_minutes(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "service_refresh_rate_in_minutes", value)

    @property
    @pulumi.getter(name="volumeSelectionTags")
    def volume_selection_tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A string->string map of allow list of volume tag-value pairs (in AWS).
        If the volume's AWS tags match this allow list, CloudWatch data about this volume is ingested.
        Multiple entries are OR'ed.
        """
        return pulumi.get(self, "volume_selection_tags")

    @volume_selection_tags.setter
    def volume_selection_tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "volume_selection_tags", value)


class CloudIntegrationCloudWatch(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 additional_tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 external_id: Optional[pulumi.Input[str]] = None,
                 force_save: Optional[pulumi.Input[bool]] = None,
                 instance_selection_tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 metric_filter_regex: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespaces: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 point_tag_filter_regex: Optional[pulumi.Input[str]] = None,
                 role_arn: Optional[pulumi.Input[str]] = None,
                 service: Optional[pulumi.Input[str]] = None,
                 service_refresh_rate_in_minutes: Optional[pulumi.Input[int]] = None,
                 volume_selection_tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Provides a Wavefront Cloud Integration for CloudWatch. This allows CloudWatch cloud integrations to be created,
        updated, and deleted.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_wavefront as wavefront

        ext_id = wavefront.CloudIntegrationAwsExternalId("ext_id")
        cloudwatch = wavefront.CloudIntegrationCloudWatch("cloudwatch",
            name="Test Integration",
            force_save=True,
            role_arn="arn:aws::1234567:role/example-arn",
            external_id=ext_id.id)
        ```

        ## Import

        CloudWatch Cloud Integrations can be imported by using the `id`, e.g.:

        ```sh
        $ pulumi import wavefront:index/cloudIntegrationCloudWatch:CloudIntegrationCloudWatch cloudwatch a411c16b-3cf7-4f03-bf11-8ca05aab898d
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] additional_tags: A list of point tag key-values to add to every point ingested using this integration.
        :param pulumi.Input[str] external_id: The Role ARN that the customer has created in AWS IAM to allow access to Wavefront.
        :param pulumi.Input[bool] force_save: Forces this resource to save, even if errors are present.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] instance_selection_tags: A string->string map allow list of instance tag-value pairs (in AWS).
               If the instance's AWS tags match this allow list, CloudWatch data about this instance is ingested.
               Multiple entries are OR'ed.
        :param pulumi.Input[str] metric_filter_regex: A regular expression that a CloudWatch metric name must match (case-insensitively) in order to be ingested.
        :param pulumi.Input[str] name: The human-readable name of this integration.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] namespaces: A list of namespaces that limit what we query from CloudWatch.
        :param pulumi.Input[str] point_tag_filter_regex: A regular expression that AWS tag key name must match (case-insensitively)
               in order to be ingested.
        :param pulumi.Input[str] role_arn: The external ID corresponding to the Role ARN.
        :param pulumi.Input[str] service: A value denoting which cloud service this service integrates with.
        :param pulumi.Input[int] service_refresh_rate_in_minutes: How often, in minutes, to refresh the service.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] volume_selection_tags: A string->string map of allow list of volume tag-value pairs (in AWS).
               If the volume's AWS tags match this allow list, CloudWatch data about this volume is ingested.
               Multiple entries are OR'ed.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CloudIntegrationCloudWatchArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Wavefront Cloud Integration for CloudWatch. This allows CloudWatch cloud integrations to be created,
        updated, and deleted.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_wavefront as wavefront

        ext_id = wavefront.CloudIntegrationAwsExternalId("ext_id")
        cloudwatch = wavefront.CloudIntegrationCloudWatch("cloudwatch",
            name="Test Integration",
            force_save=True,
            role_arn="arn:aws::1234567:role/example-arn",
            external_id=ext_id.id)
        ```

        ## Import

        CloudWatch Cloud Integrations can be imported by using the `id`, e.g.:

        ```sh
        $ pulumi import wavefront:index/cloudIntegrationCloudWatch:CloudIntegrationCloudWatch cloudwatch a411c16b-3cf7-4f03-bf11-8ca05aab898d
        ```

        :param str resource_name: The name of the resource.
        :param CloudIntegrationCloudWatchArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CloudIntegrationCloudWatchArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 additional_tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 external_id: Optional[pulumi.Input[str]] = None,
                 force_save: Optional[pulumi.Input[bool]] = None,
                 instance_selection_tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 metric_filter_regex: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespaces: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 point_tag_filter_regex: Optional[pulumi.Input[str]] = None,
                 role_arn: Optional[pulumi.Input[str]] = None,
                 service: Optional[pulumi.Input[str]] = None,
                 service_refresh_rate_in_minutes: Optional[pulumi.Input[int]] = None,
                 volume_selection_tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CloudIntegrationCloudWatchArgs.__new__(CloudIntegrationCloudWatchArgs)

            __props__.__dict__["additional_tags"] = additional_tags
            if external_id is None and not opts.urn:
                raise TypeError("Missing required property 'external_id'")
            __props__.__dict__["external_id"] = external_id
            __props__.__dict__["force_save"] = force_save
            __props__.__dict__["instance_selection_tags"] = instance_selection_tags
            __props__.__dict__["metric_filter_regex"] = metric_filter_regex
            __props__.__dict__["name"] = name
            __props__.__dict__["namespaces"] = namespaces
            __props__.__dict__["point_tag_filter_regex"] = point_tag_filter_regex
            if role_arn is None and not opts.urn:
                raise TypeError("Missing required property 'role_arn'")
            __props__.__dict__["role_arn"] = role_arn
            if service is None and not opts.urn:
                raise TypeError("Missing required property 'service'")
            __props__.__dict__["service"] = service
            __props__.__dict__["service_refresh_rate_in_minutes"] = service_refresh_rate_in_minutes
            __props__.__dict__["volume_selection_tags"] = volume_selection_tags
        super(CloudIntegrationCloudWatch, __self__).__init__(
            'wavefront:index/cloudIntegrationCloudWatch:CloudIntegrationCloudWatch',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            additional_tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            external_id: Optional[pulumi.Input[str]] = None,
            force_save: Optional[pulumi.Input[bool]] = None,
            instance_selection_tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            metric_filter_regex: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            namespaces: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            point_tag_filter_regex: Optional[pulumi.Input[str]] = None,
            role_arn: Optional[pulumi.Input[str]] = None,
            service: Optional[pulumi.Input[str]] = None,
            service_refresh_rate_in_minutes: Optional[pulumi.Input[int]] = None,
            volume_selection_tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None) -> 'CloudIntegrationCloudWatch':
        """
        Get an existing CloudIntegrationCloudWatch resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] additional_tags: A list of point tag key-values to add to every point ingested using this integration.
        :param pulumi.Input[str] external_id: The Role ARN that the customer has created in AWS IAM to allow access to Wavefront.
        :param pulumi.Input[bool] force_save: Forces this resource to save, even if errors are present.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] instance_selection_tags: A string->string map allow list of instance tag-value pairs (in AWS).
               If the instance's AWS tags match this allow list, CloudWatch data about this instance is ingested.
               Multiple entries are OR'ed.
        :param pulumi.Input[str] metric_filter_regex: A regular expression that a CloudWatch metric name must match (case-insensitively) in order to be ingested.
        :param pulumi.Input[str] name: The human-readable name of this integration.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] namespaces: A list of namespaces that limit what we query from CloudWatch.
        :param pulumi.Input[str] point_tag_filter_regex: A regular expression that AWS tag key name must match (case-insensitively)
               in order to be ingested.
        :param pulumi.Input[str] role_arn: The external ID corresponding to the Role ARN.
        :param pulumi.Input[str] service: A value denoting which cloud service this service integrates with.
        :param pulumi.Input[int] service_refresh_rate_in_minutes: How often, in minutes, to refresh the service.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] volume_selection_tags: A string->string map of allow list of volume tag-value pairs (in AWS).
               If the volume's AWS tags match this allow list, CloudWatch data about this volume is ingested.
               Multiple entries are OR'ed.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CloudIntegrationCloudWatchState.__new__(_CloudIntegrationCloudWatchState)

        __props__.__dict__["additional_tags"] = additional_tags
        __props__.__dict__["external_id"] = external_id
        __props__.__dict__["force_save"] = force_save
        __props__.__dict__["instance_selection_tags"] = instance_selection_tags
        __props__.__dict__["metric_filter_regex"] = metric_filter_regex
        __props__.__dict__["name"] = name
        __props__.__dict__["namespaces"] = namespaces
        __props__.__dict__["point_tag_filter_regex"] = point_tag_filter_regex
        __props__.__dict__["role_arn"] = role_arn
        __props__.__dict__["service"] = service
        __props__.__dict__["service_refresh_rate_in_minutes"] = service_refresh_rate_in_minutes
        __props__.__dict__["volume_selection_tags"] = volume_selection_tags
        return CloudIntegrationCloudWatch(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="additionalTags")
    def additional_tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A list of point tag key-values to add to every point ingested using this integration.
        """
        return pulumi.get(self, "additional_tags")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> pulumi.Output[str]:
        """
        The Role ARN that the customer has created in AWS IAM to allow access to Wavefront.
        """
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter(name="forceSave")
    def force_save(self) -> pulumi.Output[Optional[bool]]:
        """
        Forces this resource to save, even if errors are present.
        """
        return pulumi.get(self, "force_save")

    @property
    @pulumi.getter(name="instanceSelectionTags")
    def instance_selection_tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A string->string map allow list of instance tag-value pairs (in AWS).
        If the instance's AWS tags match this allow list, CloudWatch data about this instance is ingested.
        Multiple entries are OR'ed.
        """
        return pulumi.get(self, "instance_selection_tags")

    @property
    @pulumi.getter(name="metricFilterRegex")
    def metric_filter_regex(self) -> pulumi.Output[Optional[str]]:
        """
        A regular expression that a CloudWatch metric name must match (case-insensitively) in order to be ingested.
        """
        return pulumi.get(self, "metric_filter_regex")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The human-readable name of this integration.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def namespaces(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        A list of namespaces that limit what we query from CloudWatch.
        """
        return pulumi.get(self, "namespaces")

    @property
    @pulumi.getter(name="pointTagFilterRegex")
    def point_tag_filter_regex(self) -> pulumi.Output[Optional[str]]:
        """
        A regular expression that AWS tag key name must match (case-insensitively)
        in order to be ingested.
        """
        return pulumi.get(self, "point_tag_filter_regex")

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> pulumi.Output[str]:
        """
        The external ID corresponding to the Role ARN.
        """
        return pulumi.get(self, "role_arn")

    @property
    @pulumi.getter
    def service(self) -> pulumi.Output[str]:
        """
        A value denoting which cloud service this service integrates with.
        """
        return pulumi.get(self, "service")

    @property
    @pulumi.getter(name="serviceRefreshRateInMinutes")
    def service_refresh_rate_in_minutes(self) -> pulumi.Output[Optional[int]]:
        """
        How often, in minutes, to refresh the service.
        """
        return pulumi.get(self, "service_refresh_rate_in_minutes")

    @property
    @pulumi.getter(name="volumeSelectionTags")
    def volume_selection_tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A string->string map of allow list of volume tag-value pairs (in AWS).
        If the volume's AWS tags match this allow list, CloudWatch data about this volume is ingested.
        Multiple entries are OR'ed.
        """
        return pulumi.get(self, "volume_selection_tags")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetUserGroupResult',
    'AwaitableGetUserGroupResult',
    'get_user_group',
    'get_user_group_output',
]

@pulumi.output_type
class GetUserGroupResult:
    """
    A collection of values returned by getUserGroup.
    """
    def __init__(__self__, description=None, id=None, name=None, roles=None, users=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if roles and not isinstance(roles, list):
            raise TypeError("Expected argument 'roles' to be a list")
        pulumi.set(__self__, "roles", roles)
        if users and not isinstance(users, list):
            raise TypeError("Expected argument 'users' to be a list")
        pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Human-readable description of the group.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the group in Wavefront.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the group in Wavefront.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def roles(self) -> Sequence[str]:
        """
        The list of roles associated with the group.
        """
        return pulumi.get(self, "roles")

    @property
    @pulumi.getter
    def users(self) -> Sequence[str]:
        """
        The list of users assigned to the group.
        """
        return pulumi.get(self, "users")


class AwaitableGetUserGroupResult(GetUserGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUserGroupResult(
            description=self.description,
            id=self.id,
            name=self.name,
            roles=self.roles,
            users=self.users)


def get_user_group(id: Optional[str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUserGroupResult:
    """
    Use this data source to get information about a Wavefront user group by its ID.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_wavefront as wavefront

    # Get the information about the user group.
    example = wavefront.get_user_group(id="user-group-id")
    ```


    :param str id: The ID associated with the user group data to be fetched.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('wavefront:index/getUserGroup:getUserGroup', __args__, opts=opts, typ=GetUserGroupResult).value

    return AwaitableGetUserGroupResult(
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        roles=pulumi.get(__ret__, 'roles'),
        users=pulumi.get(__ret__, 'users'))


@_utilities.lift_output_func(get_user_group)
def get_user_group_output(id: Optional[pulumi.Input[str]] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetUserGroupResult]:
    """
    Use this data source to get information about a Wavefront user group by its ID.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_wavefront as wavefront

    # Get the information about the user group.
    example = wavefront.get_user_group(id="user-group-id")
    ```


    :param str id: The ID associated with the user group data to be fetched.
    """
    ...
